==> disable_enable_all_assign_block-8.x-1.0.tar.gz: disable_enable_all_assign_block/src/Form/DisableEnableBlockSettingsForm.php <==
<?php

namespace Drupal\disable_enable_all_assign_block\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Database\Database;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Component\Datetime\TimeInterface;
use Drupal\block\BlockRepositoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Disable and enable all assign block advanced settings.
 */
class DisableEnableBlockSettingsForm extends ConfigFormBase {

  /**
   * The cache render service.
   *
   * @var \Drupal\Core\Cache\CacheBackendInterface
   */
  protected $cacheRender;

  /**
   * The time service.
   *
   * @var \Drupal\Component\Datetime\TimeInterface
   */
  protected $time;

  /**
   * The block repository.
   *
   * @var \Drupal\block\BlockRepositoryInterface
   */
  protected $blockRepository;

  /**
   * Constructs a \Drupal\toolbar_themes\ToolbarThemesSettingsForm object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cacheRender
   *   A cache backend interface instance.
   * @param \Drupal\Component\Datetime\TimeInterface $time
   *   The time service.
   * @param \Drupal\block\BlockRepositoryInterface $block_repository
   *   The block repository.
   */
  public function __construct(ConfigFactoryInterface $config_factory, CacheBackendInterface $cacheRender, TimeInterface $time, BlockRepositoryInterface $block_repository) {
    parent::__construct($config_factory);
    $this->cacheRender = $cacheRender;
    $this->time = $time;
    $this->blockRepository = $block_repository;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('cache.config'),
      $container->get('datetime.time'),
      $container->get('block.repository')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'disable_enable_all_assign_block_settings_advanced';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'disable_enable_all_assign_block.settings_advanced',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);
    $settings = $this->config('disable_enable_all_assign_block.settings_advanced');
    // Load all region content assigned via blocks.
    $cacheable_metadata_list = [];
    $region = $this->blockRepository->getVisibleBlocksPerRegion($cacheable_metadata_list);
    $region_list = json_decode(json_encode(system_region_list($this->config('system.theme')->get('default'), $region)), TRUE);
    $form['#tree'] = TRUE;
    $form['daab_region'] = [
      '#type'          => 'checkboxes',
      '#title' => $this->t('All region'),
      '#options' => $region_list,
      '#default_value' => $settings->get('daab_region'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Get frontend theme name.
    $defaultThemeName = $this->config('system.theme')->get('default');
    // Get db conntection.
    $connection = Database::getConnection();
    // Admin setting config.
    $settings = $this->configFactory->getEditable('disable_enable_all_assign_block.settings_advanced');
    // Set value.
    $settings->set('daab_region', $form_state->getValue('daab_region'))->save();
    // Count number of region greater than 1.
    if (count($form_state->getValue('daab_region')) > 1) {
      foreach ($form_state->getValue('daab_region') as $key => $value) {
        // Count number checked region inserted into the table.
        $query = $connection->select('disable_enable_all_assign_block')
          ->fields('disable_enable_all_assign_block', ['region'])
          ->condition('region', $key)
          ->execute();
        $query->allowRowCount = TRUE;
        $count = $query->rowCount();
        // Check condtion inserted region and region value.
        if ($count === 0 && $value === 0) {
          // Insert data in table.
          $result = $connection->insert('disable_enable_all_assign_block')
            ->fields([
              'region' => $key,
              'status' => 0,
              'created' => $this->time->getRequestTime(),
              'updated' => $this->time->getRequestTime(),
            ])
            ->execute();
        }
        elseif ($count === 1 && $value !== 0) {
          // Update data in table.
          $connection->update('disable_enable_all_assign_block')
            ->fields([
              'status' => 1,
              'updated' => $this->time->getRequestTime(),
            ])
            ->condition('region', $key)
            ->execute();
        }
        elseif ($count === 0 && $value !== 0) {
          // Insert data in table.
          $connection->insert('disable_enable_all_assign_block')
            ->fields([
              'region' => $key,
              'status' => 1,
              'created' => $this->time->getRequestTime(),
              'updated' => $this->time->getRequestTime(),
            ])
            ->execute();
        }
        elseif ($count === 1 && $value === 0) {
          // Update data in table.
          $connection->update('disable_enable_all_assign_block')
            ->fields([
              'status' => 0,
              'updated' => $this->time->getRequestTime(),
            ])
            ->condition('region', $key)
            ->execute();
        }
      }
    }
    else {
      $result = $connection->insert('disable_enable_all_assign_block')
        ->fields([
          'region' => $form_state->getValue('daab_region'),
          'status' => 1,
          'created' => $this->time->getRequestTime(),
          'updated' => $this->time->getRequestTime(),
        ])
        ->execute();
    }
    // Fetch all block config from the table.
    $regions = [];
    $extensions = $connection->select('config')
      ->fields('config', ['data'])
      ->condition('collection', '')
      ->condition('name', 'block.block.%', 'LIKE')
      ->execute()->fetchCol();
    foreach ($extensions as $svalue) {
      $unserialize = unserialize($svalue);
      if ($unserialize['theme'] == $defaultThemeName) {
        $regions[$unserialize['id']] = $unserialize['region'];
      }
    }
    // Match checked checkbox.
    $statuscheckquery = $connection->select('disable_enable_all_assign_block')
      ->fields('disable_enable_all_assign_block', ['region'])
      ->condition('status', 1)
      ->execute()->fetchCol();
    $result = array_intersect($regions, $statuscheckquery);
    foreach ($result as $key => $value) {
      $extensions = $connection->select('config')
        ->fields('config', ['data'])
        ->condition('collection', '')
        ->condition('name', 'block.block.' . $key)
        ->execute()->fetchField();
      $extensions = unserialize($extensions);
      $extensions['status'] = 0;
      $connection->update('config')
        ->fields([
          'data' => serialize($extensions),
        ])
        ->condition('collection', '')
        ->condition('name', 'block.block.' . $key)
        ->execute();
      $this->cacheRender->invalidate('block.block.' . $key);
    }
    // Match un-checked checkbox.
    $statuscheckquery = $connection->select('disable_enable_all_assign_block')
      ->fields('disable_enable_all_assign_block', ['region'])
      ->condition('status', 0)
      ->execute()->fetchCol();
    $results = array_intersect($regions, $statuscheckquery);
    foreach ($results as $key => $value) {
      $extensions = $connection->select('config')
        ->fields('config', ['data'])
        ->condition('collection', '')
        ->condition('name', 'block.block.' . $key)
        ->execute()->fetchField();
      $extensions = unserialize($extensions);
      $extensions['status'] = 1;
      $connection->update('config')
        ->fields([
          'data' => serialize($extensions),
        ])
        ->condition('collection', '')
        ->condition('name', 'block.block.' . $key)
        ->execute();
      $this->cacheRender->invalidate('block.block.' . $key);
    }
    $this->messenger()->addMessage($this->t('Configuration has been set.'));
  }

}

==> disable_enable_all_assign_block-8.x-1.1.tar.gz: disable_enable_all_assign_block/src/Form/DisableEnableBlockSettingsForm.php <==
<?php

namespace Drupal\disable_enable_all_assign_block\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Database\Database;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Component\Datetime\TimeInterface;
use Drupal\block\BlockRepositoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Disable and enable all assign block advanced settings.
 */
class DisableEnableBlockSettingsForm extends ConfigFormBase {

  /**
   * The cache render service.
   *
   * @var \Drupal\Core\Cache\CacheBackendInterface
   */
  protected $cacheRender;

  /**
   * The time service.
   *
   * @var \Drupal\Component\Datetime\TimeInterface
   */
  protected $time;

  /**
   * The block repository.
   *
   * @var \Drupal\block\BlockRepositoryInterface
   */
  protected $blockRepository;

  /**
   * Constructs a \Drupal\toolbar_themes\ToolbarThemesSettingsForm object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cacheRender
   *   A cache backend interface instance.
   * @param \Drupal\Component\Datetime\TimeInterface $time
   *   The time service.
   * @param \Drupal\block\BlockRepositoryInterface $block_repository
   *   The block repository.
   */
  public function __construct(ConfigFactoryInterface $config_factory, CacheBackendInterface $cacheRender, TimeInterface $time, BlockRepositoryInterface $block_repository) {
    parent::__construct($config_factory);
    $this->cacheRender = $cacheRender;
    $this->time = $time;
    $this->blockRepository = $block_repository;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('cache.config'),
      $container->get('datetime.time'),
      $container->get('block.repository')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'disable_enable_all_assign_block_settings_advanced';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'disable_enable_all_assign_block.settings_advanced',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);
    $settings = $this->config('disable_enable_all_assign_block.settings_advanced');
    // Load all region content assigned via blocks.
    $cacheable_metadata_list = [];
    $region = $this->blockRepository->getVisibleBlocksPerRegion($cacheable_metadata_list);
    $region_list = json_decode(json_encode(system_region_list($this->config('system.theme')->get('default'), $region)), TRUE);
    $form['#tree'] = TRUE;
    $form['daab_region'] = [
      '#type'          => 'checkboxes',
      '#title' => $this->t('All region'),
      '#options' => $region_list,
      '#default_value' => $settings->get('daab_region') ?:[],
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Get frontend theme name.
    $defaultThemeName = $this->config('system.theme')->get('default');
    // Get db conntection.
    $connection = Database::getConnection();
    // Admin setting config.
    $settings = $this->configFactory->getEditable('disable_enable_all_assign_block.settings_advanced');
    // Set value.
    $settings->set('daab_region', $form_state->getValue('daab_region'))->save();
    // Count number of region greater than 1.
    if (count($form_state->getValue('daab_region')) > 1) {
      foreach ($form_state->getValue('daab_region') as $key => $value) {
        // Count number checked region inserted into the table.
        $query = $connection->select('disable_enable_all_assign_block')
          ->fields('disable_enable_all_assign_block', ['region'])
          ->condition('region', $key)
          ->execute();
        $query->allowRowCount = TRUE;
        $count = $query->rowCount();
        // Check condtion inserted region and region value.
        if ($count === 0 && $value === 0) {
          // Insert data in table.
          $result = $connection->insert('disable_enable_all_assign_block')
            ->fields([
              'region' => $key,
              'status' => 0,
              'created' => $this->time->getRequestTime(),
              'updated' => $this->time->getRequestTime(),
            ])
            ->execute();
        }
        elseif ($count === 1 && $value !== 0) {
          // Update data in table.
          $connection->update('disable_enable_all_assign_block')
            ->fields([
              'status' => 1,
              'updated' => $this->time->getRequestTime(),
            ])
            ->condition('region', $key)
            ->execute();
        }
        elseif ($count === 0 && $value !== 0) {
          // Insert data in table.
          $connection->insert('disable_enable_all_assign_block')
            ->fields([
              'region' => $key,
              'status' => 1,
              'created' => $this->time->getRequestTime(),
              'updated' => $this->time->getRequestTime(),
            ])
            ->execute();
        }
        elseif ($count === 1 && $value === 0) {
          // Update data in table.
          $connection->update('disable_enable_all_assign_block')
            ->fields([
              'status' => 0,
              'updated' => $this->time->getRequestTime(),
            ])
            ->condition('region', $key)
            ->execute();
        }
      }
    }
    else {
      $result = $connection->insert('disable_enable_all_assign_block')
        ->fields([
          'region' => $form_state->getValue('daab_region'),
          'status' => 1,
          'created' => $this->time->getRequestTime(),
          'updated' => $this->time->getRequestTime(),
        ])
        ->execute();
    }
    // Fetch all block config from the table.
    $regions = [];
    $extensions = $connection->select('config')
      ->fields('config', ['data'])
      ->condition('collection', '')
      ->condition('name', 'block.block.%', 'LIKE')
      ->execute()->fetchCol();
    foreach ($extensions as $svalue) {
      $unserialize = unserialize($svalue);
      if ($unserialize['theme'] == $defaultThemeName) {
        $regions[$unserialize['id']] = $unserialize['region'];
      }
    }
    // Match checked checkbox.
    $statuscheckquery = $connection->select('disable_enable_all_assign_block')
      ->fields('disable_enable_all_assign_block', ['region'])
      ->condition('status', 1)
      ->execute()->fetchCol();
    $result = array_intersect($regions, $statuscheckquery);
    foreach ($result as $key => $value) {
      $extensions = $connection->select('config')
        ->fields('config', ['data'])
        ->condition('collection', '')
        ->condition('name', 'block.block.' . $key)
        ->execute()->fetchField();
      $extensions = unserialize($extensions);
      $extensions['status'] = 0;
      $connection->update('config')
        ->fields([
          'data' => serialize($extensions),
        ])
        ->condition('collection', '')
        ->condition('name', 'block.block.' . $key)
        ->execute();
      $this->cacheRender->invalidate('block.block.' . $key);
    }
    // Match un-checked checkbox.
    $statuscheckquery = $connection->select('disable_enable_all_assign_block')
      ->fields('disable_enable_all_assign_block', ['region'])
      ->condition('status', 0)
      ->execute()->fetchCol();
    $results = array_intersect($regions, $statuscheckquery);
    foreach ($results as $key => $value) {
      $extensions = $connection->select('config')
        ->fields('config', ['data'])
        ->condition('collection', '')
        ->condition('name', 'block.block.' . $key)
        ->execute()->fetchField();
      $extensions = unserialize($extensions);
      $extensions['status'] = 1;
      $connection->update('config')
        ->fields([
          'data' => serialize($extensions),
        ])
        ->condition('collection', '')
        ->condition('name', 'block.block.' . $key)
        ->execute();
      $this->cacheRender->invalidate('block.block.' . $key);
    }
    $this->messenger()->addMessage($this->t('Configuration has been set.'));
  }

}
